@@ -92,13 +92,18 @@ default_user_agent = "OSMnx Python package (https://github.com/gboeing/osmnx)"
 default_referer = "OSMnx Python package (https://github.com/gboeing/osmnx)"
 default_accept_language = "en"
 
-# which API endpoint to use for nominatim queries
-# and your API key, if you are using a commercial endpoint that requires it
+# base API endpoint to use for nominatim queries
+# and your nominatim API key, if you are using a host that requires one
 nominatim_endpoint = "https://nominatim.openstreetmap.org/"
 nominatim_key = None
 
-# which API endpoint to use for overpass queries
-overpass_endpoint = "http://overpass-api.de/api"
+# base API endpoint to use for overpass queries
+overpass_endpoint = "https://overpass-api.de/api"
+
+# whether to check the overpass server status endpoint for how long to pause
+# between requests: necessary if server uses slot management, but can be set
+# to False if you are running your own overpass instance without rate limiting
+overpass_rate_limit = True
 
 # which API provider to use for adding node elevations. default is "google"
 # for Google Maps Elevation API but also accepts "airmap"
